==> babel-plugin-undeclared-variables-check-with-config-0.0.4.tgz: package/lib/index.js <==
'use strict';

var _typeof2 = require('babel-runtime/helpers/typeof');

var _typeof3 = _interopRequireDefault(_typeof2);

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _globals = require('globals');

var _globals2 = _interopRequireDefault(_globals);

var _leven = require('leven');

var _leven2 = _interopRequireDefault(_leven);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = function (_ref) {
  var messages = _ref.messages;

  return {
    visitor: {
      ReferencedIdentifier: function ReferencedIdentifier(path) {
        var node = path.node;

        // a bug in babel means you have to walk the entire parent path if you want to ensure you have actually seen
        // all scopes

        var pp = path;
        while (pp) {
          var scope = pp.scope;

          var binding = scope.getBinding(node.name);
          if (binding && binding.kind === "type" && !path.parentPath.isFlow()) {
            throw path.buildCodeFrameError(messages.get("undeclaredVariableType", node.name), ReferenceError);
          }

          if (scope.hasBinding(node.name)) {
            return;
          }

          // babel sometimes struggles to notice that variables declared in the `init` portion of loops are available
          // throughout the loop
          if (pp.node.type === 'ForStatement' && pp.node.init.type === 'VariableDeclaration') {
            var _ret = function () {
              var name = (0, _stringify2.default)(node.name);
              if (pp.node.init.declarations.some(function (_ref2) {
                var id = _ref2.id;

                if (id.type === 'Identifier') {
                  return id.name === node.name;
                }
                return (0, _stringify2.default)(id).indexOf(name) !== -1;
              })) {
                return {
                  v: void 0
                };
              }
            }();

            if ((typeof _ret === 'undefined' ? 'undefined' : (0, _typeof3.default)(_ret)) === "object") return _ret.v;
          }

          pp = pp.parentPath;
        }

        var opts = this.opts;
        if (opts && Array.isArray(opts.globals) && opts.globals.indexOf(node.name) !== -1) {
          return;
        }
        var builtins = opts && Array.isArray(opts.builtins) ? opts.builtins : ['builtin', 'browser', 'worker', 'node', 'jest', 'jquery', 'serviceworker', 'webextensions'];
        if (builtins.some(function (b) {
          return typeof _globals2.default[b][node.name] === 'boolean';
        })) {
          return;
        }

        // get the closest declaration to offer as a suggestion
        // the variable name may have just been mistyped

        var bindings = path.scope.getAllBindings();

        var closest = void 0;
        var shortest = -1;

        for (var name in bindings) {
          var distance = (0, _leven2.default)(node.name, name);
          if (distance <= 0 || distance > 3) continue;
          if (distance >= node.name.length) continue;
          if (distance >= name.length) continue;
          if (distance <= shortest) continue;

          closest = name;
          shortest = distance;
        }

        var msg = void 0;
        if (closest) {
          msg = messages.get("undeclaredVariableSuggestion", node.name, closest);
        } else {
          msg = messages.get("undeclaredVariable", node.name);
        }

        throw path.buildCodeFrameError(msg, ReferenceError);
      }
    }
  };
};

==> babel-plugin-undeclared-variables-check-with-config-0.0.5.tgz: package/lib/index.js <==
'use strict';

var _typeof2 = require('babel-runtime/helpers/typeof');

var _typeof3 = _interopRequireDefault(_typeof2);

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _globals = require('globals');

var _globals2 = _interopRequireDefault(_globals);

var _leven = require('leven');

var _leven2 = _interopRequireDefault(_leven);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = function (_ref) {
  var messages = _ref.messages;

  return {
    pre: function pre(file) {
      var _this = this;

      this.commmentGlobals = [];
      file.ast.comments.forEach(function (_ref2) {
        var value = _ref2.value;

        var v = value.trim();
        if (/^global /.test(v)) {
          v.replace(/^global /, '').split(',').forEach(function (name) {
            _this.commmentGlobals.push(name.trim());
          });
        }
      });
    },

    visitor: {
      ReferencedIdentifier: function ReferencedIdentifier(path) {
        var node = path.node;

        // a bug in babel means you have to walk the entire parent path if you want to ensure you have actually seen
        // all scopes

        var pp = path;
        while (pp) {
          var scope = pp.scope;

          var binding = scope.getBinding(node.name);
          if (binding && binding.kind === "type" && !path.parentPath.isFlow()) {
            throw path.buildCodeFrameError(messages.get("undeclaredVariableType", node.name), ReferenceError);
          }

          if (scope.hasBinding(node.name)) {
            return;
          }

          // babel sometimes struggles to notice that variables declared in the `init` portion of loops are available
          // throughout the loop
          if (pp.node.type === 'ForStatement' && pp.node.init.type === 'VariableDeclaration') {
            var _ret = function () {
              var name = (0, _stringify2.default)(node.name);
              if (pp.node.init.declarations.some(function (_ref3) {
                var id = _ref3.id;

                if (id.type === 'Identifier') {
                  return id.name === node.name;
                }
                return (0, _stringify2.default)(id).indexOf(name) !== -1;
              })) {
                return {
                  v: void 0
                };
              }
            }();

            if ((typeof _ret === 'undefined' ? 'undefined' : (0, _typeof3.default)(_ret)) === "object") return _ret.v;
          }

          pp = pp.parentPath;
        }

        var opts = this.opts;
        if (opts && Array.isArray(opts.globals) && opts.globals.indexOf(node.name) !== -1) {
          return;
        }
        var builtins = opts && Array.isArray(opts.builtins) ? opts.builtins : ['builtin', 'browser', 'worker', 'node', 'jest', 'jquery', 'serviceworker', 'webextensions'];
        if (builtins.some(function (b) {
          return typeof _globals2.default[b][node.name] === 'boolean';
        })) {
          return;
        }
        if (this.commmentGlobals.indexOf(node.name) !== -1) {
          return;
        }

        // get the closest declaration to offer as a suggestion
        // the variable name may have just been mistyped

        var bindings = path.scope.getAllBindings();

        var closest = void 0;
        var shortest = -1;

        for (var name in bindings) {
          var distance = (0, _leven2.default)(node.name, name);
          if (distance <= 0 || distance > 3) continue;
          if (distance >= node.name.length) continue;
          if (distance >= name.length) continue;
          if (distance <= shortest) continue;

          closest = name;
          shortest = distance;
        }

        var msg = void 0;
        if (closest) {
          msg = messages.get("undeclaredVariableSuggestion", node.name, closest);
        } else {
          msg = messages.get("undeclaredVariable", node.name);
        }

        throw path.buildCodeFrameError(msg, ReferenceError);
      }
    }
  };
};
